@@ -525,3 +525,37 @@ pub fn dissoc(xs: &CalcitItems) -> Result<Calcit, String> {
     (_, _) => Err(format!("list dissoc expected 2 arguments, got: {:?}", xs)),
   }
 }
+
+pub fn list_to_set(xs: &CalcitItems) -> Result<Calcit, String> {
+  if xs.len() != 1 {
+    return Err(format!("&list:to-set expected a single argument in list, got {:?}", xs));
+  }
+  match &xs[0] {
+    Calcit::List(ys) => {
+      let mut zs = im::HashSet::new();
+      for y in ys {
+        zs.insert(y.clone());
+      }
+      Ok(Calcit::Set(zs))
+    }
+    a => Err(format!("&list:to-set expected a list, got {}", a)),
+  }
+}
+
+pub fn distinct(xs: &CalcitItems) -> Result<Calcit, String> {
+  if xs.len() != 1 {
+    return Err(format!("&list:to-set expected a single argument in list, got {:?}", xs));
+  }
+  match &xs[0] {
+    Calcit::List(ys) => {
+      let mut zs = im::Vector::new();
+      for y in ys {
+        if !zs.contains(y) {
+          zs.push_back(y.clone());
+        }
+      }
+      Ok(Calcit::List(zs))
+    }
+    a => Err(format!("&list:to-set expected a list, got {}", a)),
+  }
+}
